@@ -38,7 +38,9 @@
     function iad_params($params) {
 	$base = array(NULL,NULL,NULL,NULL);
 	$params[2] = true;
-	$params[3] = ($_SERVER["argv"][3]=="nolog")?false:true; // Do not insert events
+    $params[3] = true;
+    if (isset($_SERVER['argv'][3]) && $_SERVER['argv'][3]== 'nolog')
+        $params[3] = false; // Do no insert events
 
 	foreach ($params as $pos=>$value)
 	    $base[$pos] = $value;
@@ -339,6 +341,7 @@
 	$ad_time = round(time_usec_diff($ad_time));
 	logger("H ".str_pad($host_id,3," ",STR_PAD_LEFT)." : Autodiscovery took ".$ad_time." msec.\n");
 
+    if (!$output)
         ob_end_clean();
 
 	return array("times"=>$ad_time);
