@@ -4,14 +4,24 @@
  * This program is licensed under the GNU GPL, full terms in the LICENSE file
  */
 
-    // backend_paramters = EventTypeId (to generate the alarm),[alarm_state|nothing] (if result is empty what to use), time_wait (seconds to wait before between down and up events
+    // backend_parameters = EventTypeId (to generate the alarm),[alarm_state|nothing] (if result is empty what to use), time_wait (seconds to wait before between down and up events
 
 function backend_alarm($options,$alarm_description) {
     
-    //if we recieved an | in the result, parse it to use the right part as th event_info for the new event
-    if (strpos($alarm_description,"|")!==FALSE) list ($alarm_description,$event_info) = explode ("|",$alarm_description);
-    if (strpos($alarm_description,";")!==FALSE) list ($alarm_description,$event_info) = explode (";",$alarm_description);
+    if (is_string($alarm_description)) { // This is used with the pollers
 
+	//if we recieved an | in the result, parse it to use the right part as th event_info for the new event
+    
+	if (strpos($alarm_description,"|")!==FALSE) list ($alarm_description,$event_info) = explode ("|",$alarm_description);
+	if (strpos($alarm_description,";")!==FALSE) list ($alarm_description,$event_info) = explode (";",$alarm_description);
+
+    } else {				// this is used by the trap system
+
+	$alarm_description = $options["status"];
+	$event_info = $options["info"];
+    }
+
+    
     // Parse paramters
     list($event_type_id,$assume,$time_wait) = explode(",",$options["backend_parameters"]);
 
@@ -30,7 +40,8 @@ function backend_alarm($options,$alarm_description) {
         
     if ($event_type_id && $alarm_state) { 
 	$now = time();
-	$now_date = date("Y-m-d H:i:s",$now);
+	$now_date = (isset($options["date"])?$options["date"]:date("Y-m-d H:i:s",$now)); // use date set in the params (traps), or now 
+	
 	$processed = 0;
 	
 	$other_alarm = have_other_alarm($options["interface_id"],$event_type_id,array(ALARM_DOWN,ALARM_TESTING));
