@@ -22,7 +22,7 @@
 	
     include_once('consolidate/syslog.php');
 	include_once('consolidate/traps.php');
-	include_once('consolidate/logfiles.php');
+	//include_once('consolidate/logfiles.php');
     include_once('consolidate/tacacs.php');
 
 	logger ("Consolidator Starting...\n");
@@ -33,7 +33,7 @@
         consolidate_syslog();
         consolidate_tacacs();
 		consolidate_traps();
-		consolidate_logfiles();
+		//consolidate_logfiles();
 		flush();
 		
 		include("consolidate/events.php"); flush();
