@@ -7,6 +7,7 @@
 DEFINE( phydrv ,'.1.3.6.1.4.1.232.3.2.5.1.1.');
 DEFINE( fans, '.1.3.6.1.4.1.232.6.2.6.7.1.');
 DEFINE( temp, '.1.3.6.1.4.1.232.6.2.6.8.1.');
+DEFINE( power, '.1.3.6.1.4.1.232.6.2.9.3.1.');
 function discovery_cpqmib ($ip, $rocommunity, $hostid, $param)
 {
 	$disc_type = $param;
@@ -80,6 +81,25 @@ function discovery_cpqmib ($ip, $rocommunity, $hostid, $param)
 			    }
 			}
 			break;
+		case 'powersupply':
+			$chassis = snmp_walk($ip, $rocommunity, power.'1');
+
+			if (is_array($chassis)) {
+			    $bayindex = snmp_walk($ip, $rocommunity, power.'2');
+			    $present = snmp_walk($ip, $rocommunity, power.'3');
+			    $condition = snmp_walk($ip, $rocommunity, power.'4');
+
+			    foreach($chassis as $key => $cha) {
+				$interfaces[$ifnum++] = array(
+					'interface' => "Power $cha/$bayindex[$key]" ,
+					'chassis' => $cha,
+					'bayindex' => $bayindex[$key],
+					'admin' => $present[$key]==3?'up':'down',
+					'oper' => $condition[$key]==2?'up':'down',
+				);
+			    }
+			}
+			break;
 	} // switch
 
 	return $interfaces;
