@@ -1,4 +1,8 @@
 <?
+/* This file is part of JFFNMS
+ * Copyright (C) <2002-2005> Javier Szyszlican <javier@szysz.com>
+ * This program is licensed under the GNU GPL, full terms in the LICENSE file
+ */
     //it takes all the interfaces on ID and makes an aggregated graph
 
 function graph_packets_aggregation ($data) { 
@@ -10,7 +14,7 @@ function graph_packets_aggregation ($data) {
     foreach ($data[id] as $id) {
 	$interface=$data[$id];
 
-	$opts_agg = array_merge ($opts_agg,rrdtool_get_def($interface,array("input$id"=>"inpackets","output$id"=>"outpackets")));
+	$opts_agg = @array_merge ($opts_agg,rrdtool_get_def($interface,array("input$id"=>"inpackets","output$id"=>"outpackets")));
 
 	$str_cdef_in  .="input$id,UN,0,input$id,IF,+,";	    	
 	$str_cdef_out .="output$id,UN,0,output$id,IF,+,";	    	
