@@ -1,4 +1,8 @@
 <?
+/* This file is part of JFFNMS
+ * Copyright (C) <2002-2005> Javier Szyszlican <javier@szysz.com>
+ * This program is licensed under the GNU GPL, full terms in the LICENSE file
+ */
     //it takes all the interfaces on ID and makes an aggregated graph
 
 function graph_traffic_aggregation ($data) { 
@@ -33,8 +37,8 @@ function graph_traffic_aggregation ($data) {
     $opts_GRAPH = array( 		    
 	"CDEF:inputbits=input,UN,0,input,IF,8,*",
 	"CDEF:outputbits=output,UN,0,output,IF,8,*",	
-	"CDEF:total_inputbits=inputbits,UN,0,inputbits,IF,300,*,PREV,UN,0,PREV,IF,+",
-	"CDEF:total_outputbits=outputbits,UN,0,outputbits,IF,300,*,PREV,UN,0,PREV,IF,+",
+	//"CDEF:total_inputbits=inputbits,UN,0,inputbits,IF,300,*,PREV,UN,0,PREV,IF,+",
+	//"CDEF:total_outputbits=outputbits,UN,0,outputbits,IF,300,*,PREV,UN,0,PREV,IF,+",
 
 	"HRULE:$bandwidthin#FF0000:' '",
 	"COMMENT:'Inbound Bandwidth: $bandwidthin_k kbps'",     
@@ -45,14 +49,14 @@ function graph_traffic_aggregation ($data) {
 	"AREA:inputbits#00CC00:'Inbound '",
     	"GPRINT:inputbits:MAX:'Max\:%8.2lf %sbps'",
     	"GPRINT:inputbits:AVERAGE:'Average\:%8.2lf %sbps'",
-    	"GPRINT:inputbits:LAST:'Last\:%8.2lf %sbps'",
-	"GPRINT:total_inputbits:MAX:'Total\:%8.2lf %sbps\\n'",
+    	"GPRINT:inputbits:LAST:'Last\:%8.2lf %sbps\\n'",
+	//"GPRINT:total_inputbits:MAX:'Total\:%8.2lf %sbps\\n'",
 
 	"LINE2:outputbits#0000FF:Outbound",
         "GPRINT:outputbits:MAX:'Max\:%8.2lf %sbps'",
         "GPRINT:outputbits:AVERAGE:'Average\:%8.2lf %sbps'",
-        "GPRINT:outputbits:LAST:'Last\:%8.2lf %sbps'",
-	"GPRINT:total_outputbits:MAX:'Total\:%8.2lf %sbps'",
+        "GPRINT:outputbits:LAST:'Last\:%8.2lf %sbps\\n'",
+	//"GPRINT:total_outputbits:MAX:'Total\:%8.2lf %sbps'",
     );
 
     $opts_header[] = "--vertical-label='Bits per Second'";
