@@ -31,7 +31,7 @@
 			    $statuses["$peer -> $reference, stratum $stratum"]=$status;
 		    }
 		    
-		    if ($peer = array_search("*",$statuses))
+		    if (($peer = array_search("*",$statuses)) || ($peer = array_search("#",$statuses)))
 			$status = "synchronized|with $peer";
 		    else
 			$status = "unsynchronized";
