@@ -1,21 +1,7 @@
 <?
-/* Host Config Downloader (via plugins)
- * Copyright (C) <2002,2003> Javier Szyszlican <javier@szysz.com>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+/* Host Config Downloader (via plugins). This file is part of JFFNMS
+ * Copyright (C) <2002-2003> Javier Szyszlican <javier@szysz.com>
+ * This program is licensed under the GNU GPL, full terms in the LICENSE file
  */
  
     $jffnms_functions_include="engine";
@@ -84,7 +70,10 @@
 		        $config_data_old = $aux["config"];
 			$config_id_old = $aux["id"];
 			unset ($aux);
-			
+
+			//Cisco Router NTP fix
+			$config_data = preg_replace('/ntp clock-period \S+/', '', $config_data);
+				
 			if (md5 ($config_data) != md5 ($config_data_old)) { //if the old and the new config are not equal
 		
 			    $config_data = str_replace ("'","\'",$config_data); //escape '
