@@ -737,7 +737,8 @@
             NULL)
     );
 
-	
+    if (!$_GET['admin_structure'])
+       $_GET['admin_structure'] = $_POST['admin_structure'];
 
     if ($admin_structure=="list_all") { 
 	foreach (array_keys($structures) as $aux) 
