@@ -29,12 +29,14 @@
 	"nad"			=>array("title"=>"Network Discovery",	"type"=>"admframe",				"image"=>"world"),
 
 	"events"	=>array("title"=>"Event Analyzer", "image"=>"event",
-	    "items"	=>array("severity","event_types","syslog_types","trap_receivers","receiver_backends","alarm_states")),
+	    "items"	=>array("severity","event_types","syslog_types","trap_receivers","receiver_backends","alarm_states", 'logfiles','logfiles_match_items')),
 	"severity"		=>array("title"=>"Severities",		"type"=>"standard", 				"image"=>""	),
 	"event_types"		=>array("title"=>"Event Types",		"type"=>"standard",				"image"=>"event"),
 	"syslog_types"		=>array("title"=>"Syslog Message Rules","type"=>"standard",				"image"=>""	),
 	"trap_receivers"	=>array("title"=>"SNMP Trap Receivers",		"type"=>"standard",			"image"=>""	),
 	"alarm_states"		=>array("title"=>"Alarm States & Sounds","type"=>"standard",				"image"=>"alert"),
+    'logfiles'          =>array('title'=>'Log Files','type'=>'standard', 'image'=>''),
+    'logfiles_match_items' =>array('title'=>'Log Files Match Items','type'=>'standard', 'image'=>''),
 
 	"polling"	=>array("title"=>"Polling & Discovery", "image"=>"",
 	    "items"	=>array("interface_types","pollers_groups","pollers","pollers_backend","graph_types","autodiscovery")),
