@@ -27,7 +27,7 @@
 
     echo tag("!DOCTYPE", "", "","HTML PUBLIC \"-//W3C//DTD HTML 4.01 Frameset//EN\" \"http://www.w3.org/TR/html4/frameset.dtd\"", false);
 
-    adm_header($menu." Menu","","",true);
+    adm_header("Menu","","",true);
     
     echo 
 	tag("frameset", $menu, "", $frame_def." frameborder='no' framespacing='0'").
