@@ -147,13 +147,16 @@
 	$cant = $interfaces->get($use_interfaces,$filters); //get interfaces
 
 	if ($cant > 0) {			// if we have interfaces to show
-
-	    if (function_exists("gd_info")) {	// PHP >= 4.3.0
-		$gd_aux = gd_info();		// This is to fix Debian PHP that used a not boundled GD, with other fonts
-	        $gd_font_size = (strpos($gd_aux["GD Version"],"bundled")!==false)?6:6.7;	//If its not bundled RRDtool uses 8 px fonts
-		unset ($gd_aux);
-	    } else
-		$gd_font_size = 6;
+	
+	    if (get_config_option("rrdtool_version")=="1.0") { //RRDTool 1.0.x uses its bundled GD library
+		if (function_exists("gd_info")) {	// PHP >= 4.3.0
+		    $gd_aux = gd_info();		// This is to fix Debian PHP that used a not boundled GD, with other fonts
+	    	    $gd_font_size = (strpos($gd_aux["GD Version"],"bundled")!==false)?6:6.7;	//If its not bundled RRDtool uses 8 px fonts
+		    unset ($gd_aux);
+		} else
+		    $gd_font_size = 6;
+	    } else //RRDTool 1.2.x uses a different font
+		$gd_font_size = 5;
 	
 	    while ($graph = $interfaces->fetch()) {
 		//debug ($graph);
@@ -195,7 +198,7 @@
 		    $title = str_replace("\n"," ",$title);
 		    $title = str_replace("  ","",$title);
 
-		    $len_aux1 = (($graph["graph_type_graph1_sx"])/$gd_font_size)-strlen($last_date)-2; //graph length/size of character - length of date - margin
+		    $len_aux1 = (($graph["graph_type_graph1_sx"])/$gd_font_size)-strlen($last_date)-6; //graph length/size of character - length of date - margin
 		    $title = substr($title,0,$len_aux1);
 		    $title = str_pad($title,$len_aux1," ").(($graph["last_poll_date"] > 1)?$last_date:"");
 		    
