@@ -1,4 +1,8 @@
 <?
+/* This file is part of JFFNMS
+ * Copyright (C) <2002-2005> Javier Szyszlican <javier@szysz.com>
+ * This program is licensed under the GNU GPL, full terms in the LICENSE file
+ */
     if (($id > 1) && ($host > 1)) { 
 	$interfaces_shown++;
 
@@ -12,11 +16,11 @@
 	    if ($show_rootmap==2) $small_box_color = $bgcolor_status;
 	    if ($check_status==0) $small_box_color = "777777";
 	    
-	    $text_to_show[]= "<div style='position:absolute; top:0; left:".($sizex-$small_box)."; width: $small_box; height: $small_box; ".
-		"background-color: $small_box_color;'></div>";
+	    $text_to_show[] = html("div", "", "", "", "style='position:absolute; top:0; left:".($sizex-$small_box)."; ".
+		"width: $small_box; height: $small_box; background-color: $small_box_color;'");
 	}
 	
-    	$text_to_show = trim(str_replace("\n","",join("<br>",$text_to_show)));
+    	$text_to_show = trim(str_replace("\n","",join(br(),$text_to_show)));
 
 	if ($id==$mark_interface)
 	    $border = "border-style: double;";
