@@ -1,4 +1,8 @@
 <?
+/* This file is part of JFFNMS
+ * Copyright (C) <2002-2005> Javier Szyszlican <javier@szysz.com>
+ * This program is licensed under the GNU GPL, full terms in the LICENSE file
+ */
     if (($id > 1) && ($host > 1)) {
 	$interfaces_shown++;
 
@@ -12,7 +16,7 @@
 	    
 	    if ($frame=="map") $frame = "_parent";
 	    
-	    $text  .= "\t<a target='$frame' href='$url'>$url_name</a>";
+	    $text  .= "\t".str_replace("\t","",str_replace("\n","",linktext($url_name, $url, $frame)));
 	}
 
 	$text .= "\n";
