@@ -143,29 +143,34 @@
 	return $result;
     }
 
-function db_open() {
-    global $dbhost,$dbuser,$dbpass,$db,$db_type;
+function db_open()
+{
+  global $dbhost,$dbuser,$dbpass,$db,$db_type;
 
-    switch ($db_type) {
-	case 'mysql' :	$result = @mysql_connect ($dbhost, $dbuser, $dbpass); //try to connect
-			if (is_resource($result)) //if its a valid connection
-			    mysql_select_db($db) or die ("Could not select DB - CON2".mysql_error($result)); //try to change the DB
-			break;
+  switch ($db_type)
+  {
+  case 'mysql':
+    if (($dbconn = @mysql_connect ($dbhost, $dbuser, $dbpass))===FALSE)
+      die('Unable to connect to mysql database: '.mysql_error());
+    if (mysql_select_db($db)===FALSE)
+      die('Could not select mysql database - CON2 '.mysql_error($dbconn));
+    break;
 			
-	case 'pg':	$result = pg_connect("host=$dbhost dbname=$db user=$dbuser password=$dbpass");
+  case 'pg':
+    if (($dbconn = pg_connect("host=$dbhost dbname=$db user=$dbuser password=$dbpass"))=== FALSE)
+      die('Unable to connect to postgresql database: '.pg_last_error());
 			break;
-    }
+  default:
+    die("Unknown database type '$db_type'");
+  }
 
-    if (!is_resource($result)) die ("DB($db_type): Could not connect to the Database.\n"); //print a message if we couldn't connect to the DB
-    
-    if ($result) { 
-	$db_conn = array();
-	$db_conn["handle"]=$result;
-	$db_conn["type"]=$db_type;
-    } else 
-	$db_conn = NULL;
-
-    return $db_conn;
+  if (is_resource($dbconn)) { 
+    $db_conn = array();
+    $db_conn['handle']=$dbconn;
+    $db_conn['type']=$db_type;
+  } else 
+    $db_conn = NULL;
+  return $db_conn;
 }
 
 function db_test() {
@@ -419,27 +424,38 @@ function db_copy_table ($from,$to,$cant = NULL) {
     } 
 
 
-    //Checks the DB Connection status, and tries to reconnect
-    function db_ping ($db_conn) {
+//Checks the DB Connection status, and tries to reconnect
+function db_ping ($db_conn)
+{
 
-	$result = true;
+	$result = FALSE;
+  if (!is_resource($db_conn['handle']))
+  {
+    logger('db_ping('.$db_conn['type'].') Invalid DB handle...\n');
+    die();
+  }
 
-	switch ($db_conn["type"]) {
-	    case "mysql": 	if (function_exists("mysql_ping"))
-				    $result = mysql_ping ($db_conn["handle"]);
-				break;
+  switch ($db_conn['type'])
+  {
+  case 'mysql':
+    if (!function_exists('mysql_ping'))
+      die('db_ping(): mysql database selected but no mysql_ping().');
+    $result = mysql_ping ($db_conn['handle']);
+    break;
 
-	    case "pgsql":	if (function_exists("pg_ping"))
-				    $result = pg_ping($db_conn["handle"]);
-				break;
-	}
+  case 'pgsql':
+    if (!function_exists('pg_ping'))
+      die('db_ping(): postgresql database selected but no pg_ping().');
+    $result = pg_ping($db_conn["handle"]);
+		break;
+  default:
+    die('pg_ping(): Unknown database type.');
+  }
 
-	if ($result===true) 
-	    logger("db_ping(".$db_conn["type"].") Connection to DB Restored...\n");
-	else
-	    logger("db_ping(".$db_conn["type"].") Connection to DB Lost...\n");
+  logger('db_ping('.$db_conn['type'].') Connection to DB '.
+    ($result==TRUE?'Restored':'Lost'). "...\n");
 
 	return $result;
-    }
+}
 
 ?>
