@@ -184,8 +184,8 @@
 		$server = new SOAP_Server;
 
     		$return_val = $server->buildResult($data_to_send, $a);
-		$qn =& new QName($GLOBALS["method"].'Response',"urn:JFFNMS");
-		$methodValue =& new SOAP_Value($qn->fqn(), 'Struct', $return_val);
+		$qn = new QName($GLOBALS["method"].'Response',"urn:JFFNMS");
+		$methodValue = new SOAP_Value($qn->fqn(), 'Struct', $return_val);
 
 		header("Content-Type: text/xml; charset=UTF-8");
 		$data_to_send = $server->_makeEnvelope($methodValue, $header_results, "UTF-8");
@@ -232,7 +232,7 @@
 				    require_once 'SOAP/Server.php'; 
 				    $server = new SOAP_Server;
 				
-				    $parser =& new SOAP_Parser($data_to_recv,"UTF-8",$attachments);
+				    $parser = new SOAP_Parser($data_to_recv,"UTF-8",$attachments);
 				    $data_to_recv = $server->_decode($parser->getResponse()); 
 				    $data_to_recv = object2array($data_to_recv);
 	
