@@ -19,7 +19,9 @@
 	$result_nad = db_query($query_nad);
     
 	while ($rnad = db_fetch_array($result_nad))
-	    if (strpos($rnad["network"],"/32")==false) {
+	    //if (strpos($rnad["network"],"/32")==false) 
+	    if (1==1)
+	    {
     
 		if (!isset($hosts[$rnad["host_id"]]))
 		    $hosts[$rnad["host_id"]] = array("ips"=>array(),"snmp_name"=>$rnad["snmp_name"], 
@@ -122,16 +124,15 @@
     }
 
     function nad_graph_by_host ($hosts, $ips, $networks, $host_id="", $show_all = 0) {
-
 	$hosts_ids = array();
 
 	if (isset($host_id))
 	    $hosts1 = array($host_id=>$hosts[$host_id]);
 	else
 	    $hosts1 = $hosts;
-	    
+
 	if (is_array($hosts1))
-	while (list ($host_id, $host_data) = each ($hosts1)) 
+	while (list ($host_id, $host_data) = each ($hosts1))
 	    if (($host_data["no_more"] < 1) && (count($host_data["ips"]) > 1))
 		    foreach ($host_data["ips"] as $net=>$net_data)
 			if (nad_get_bitmask($net) < 30)
@@ -147,8 +148,8 @@
 				    $host_cnx[$host_id]["hosts"][$other_host_id]=$net;
 				
 				    if (!isset($hosts1[$other_host_id]) || ($show_all==1)) {
-					$hosts1[$other_host_id]=$hosts[$other_host_id];
-				        $hosts1[$other_host_id]["no_more"]=1;
+					$hosts1[$other_host_id] = $hosts[$other_host_id];
+					$hosts1[$other_host_id]["no_more"] = 1;
 					$host_cnx[$other_host_id]=array();
 				    }
 				}
@@ -250,7 +251,6 @@
 	if (count($graph_core)!=0) {
 
 	    $graph = array_merge($graph_init, $graph_core, $graph_finish);
-	
 	    $output = nad_graph_data($graph);
 
 	    if ($params["get_data"]==true) $output[]=$params["data"];
