@@ -192,7 +192,7 @@ function select_pollers_groups ($name,$poller_group_id,$type = 0) {
 }
 
     function select_alarm_duration($name, $value, $text = 0) {
-	$alarm_duration_options = array(0=>"Default",300=>"5 Minutes",600=>"10 Minutes",1800=>"30 Minutes",3600=>"60 Minutes");
+	$alarm_duration_options = array(0=>"Default",300=>"5 Minutes",600=>"10 Minutes",900=>"15 Minutes",1800=>"30 Minutes",3600=>"60 Minutes");
 
 	if ($text==0)
 	    return select_custom($name,$alarm_duration_options,$value);
@@ -528,6 +528,10 @@ $trigger_fields = array(
 	    return $nad_deep_options[$value];
     }
 
+    function select_logfiles_match_items ($name,$id, $add_data = NULL, $onchange = "", $params = NULL) {
+    return select_object("logfiles_match_items",$name,$id,$add_data,"id","description",$params,1,$onchange);
+} 
+
     function action_dropdown ($name, $id, $actions, $selected_action = "") {
 	
 	foreach ($actions as $action=>$data)
